interface Contributor {
    /** Contributor's metadata. */
    metaData?: PersonMetaData;
    /** Whether the contributor account is a team account. */
    isTeam?: boolean | null;
    /** Date that the contributor joined the site. */
    joinedAt?: Date | null;
    /** Email address that received the invite. */
    invitedEmail?: string | null;
    /** Whether the contributor account is a client account. */
    isClient?: boolean | null;
    /**
     * Contributor's user ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
}
interface PersonMetaData {
    /** Contributor's account ID. */
    _id?: string;
    /** Contributor's full name. */
    fullName?: string | null;
    /** URL for contributor's profile image. */
    imageUrl?: string | null;
    /** Contributor's email address. */
    email?: string | null;
    /** Contributor's access to assets and their assigned role (`policy`) for that asset. */
    assignments?: Assignment[];
}
interface Assignment {
    /** Role assigned to the user. */
    policy?: AssignedPolicy;
    /** Unique ID for this specific assignment. */
    assignmentId?: string;
    /** Identity assigned to the asset in an assignment, referred to as subject. Supported subjects include user IDs, account IDs, and app IDs. */
    subject?: Subject;
}
interface AssignedPolicy {
    /** Role ID. */
    policyId?: string;
    /** Role title. */
    title?: string | null;
    /** Role description. */
    description?: string | null;
}
interface Restriction extends RestrictionRestrictionsOneOf {
    /**
     * Deprecated.
     * @deprecated
     */
    resource?: Resource;
    /** List of conditions restricting the user's access. Currently only folder conditions are supported. */
    conditions?: Conditions;
    /** Site where the assignment restrictions apply. */
    site?: SiteRestriction;
    /** Location where the assignment restrictions apply. */
    locations?: LocationsRestriction;
}
/** @oneof */
interface RestrictionRestrictionsOneOf {
    /**
     * Deprecated.
     * @deprecated
     */
    resource?: Resource;
    /** List of conditions restricting the user's access. Currently only folder conditions are supported. */
    conditions?: Conditions;
    /** Site where the assignment restrictions apply. */
    site?: SiteRestriction;
    /** Location where the assignment restrictions apply. */
    locations?: LocationsRestriction;
}
interface Resource {
    /** Resource type. */
    resourceType?: ResourceTypeWithLiterals;
    /** Resource ID. */
    _id?: string;
    value?: string | null;
}
declare enum ResourceType {
    UNKNOWN_RESOURCE_TYPE = "UNKNOWN_RESOURCE_TYPE",
    SITE = "SITE"
}
/** @enumType */
type ResourceTypeWithLiterals = ResourceType | 'UNKNOWN_RESOURCE_TYPE' | 'SITE';
interface Conditions {
    /** List of conditions. */
    conditions?: Condition[];
}
interface Condition {
    /** Condition type. */
    conditionType?: ConditionAttributeTypeWithLiterals;
    /** Condition ID. */
    _id?: string;
    /** Expected value of the condition. When `conditionType` = "FOLDER", this is the folder path. */
    value?: string | null;
}
declare enum ConditionAttributeType {
    UNKNOWN_CONDITION_TYPE = "UNKNOWN_CONDITION_TYPE",
    FOLDER = "FOLDER"
}
/** @enumType */
type ConditionAttributeTypeWithLiterals = ConditionAttributeType | 'UNKNOWN_CONDITION_TYPE' | 'FOLDER';
interface SiteRestriction {
    /** Site ID. */
    _id?: string;
    /** Site name. */
    value?: string | null;
}
interface CompanionResource {
    /** Asset ID (referred to here as resource ID). */
    _id?: string;
    /** Asset type (referred to here as resource type). as predefined in the authorization system */
    resourceType?: string;
}
interface LocationsRestriction {
    /**
     * Location IDs.
     * @format GUID
     * @maxSize 20
     */
    ids?: string[];
}
interface Subject {
    /** ID of identity assigned to the asset. */
    _id?: string;
    /** Type of identity assigned to the asset. Supported subject types include user IDs, account IDs, and app IDs. */
    subjectType?: SubjectTypeWithLiterals;
    /** Context of identity assigned to the asset. For example, a `subjectType` = `USER` will have `context` = `ACCOUNT`. */
    context?: SubjectContext;
}
declare enum SubjectType {
    UNKNOWN = "UNKNOWN",
    ACCOUNT = "ACCOUNT",
    USER = "USER",
    USER_GROUP = "USER_GROUP",
    MEMBER_GROUP = "MEMBER_GROUP",
    VISITOR_GROUP = "VISITOR_GROUP",
    EXTERNAL_APP = "EXTERNAL_APP",
    ACCOUNT_GROUP = "ACCOUNT_GROUP",
    WIX_APP = "WIX_APP"
}
/** @enumType */
type SubjectTypeWithLiterals = SubjectType | 'UNKNOWN' | 'ACCOUNT' | 'USER' | 'USER_GROUP' | 'MEMBER_GROUP' | 'VISITOR_GROUP' | 'EXTERNAL_APP' | 'ACCOUNT_GROUP' | 'WIX_APP';
interface SubjectContext {
    _id?: string;
    contextType?: SubjectContextTypeWithLiterals;
}
declare enum SubjectContextType {
    UNKNOWN_CTX = "UNKNOWN_CTX",
    ORG_CTX = "ORG_CTX",
    ACCOUNT_CTX = "ACCOUNT_CTX"
}
/** @enumType */
type SubjectContextTypeWithLiterals = SubjectContextType | 'UNKNOWN_CTX' | 'ORG_CTX' | 'ACCOUNT_CTX';
interface GetSiteContributorsRequest {
    /** The locale of the request. Defaults to en-us */
    locale?: string | null;
}
interface GetSiteContributorsResponse {
    users?: User[];
    teams?: Team[];
    invites?: SiteInvite[];
    policies?: Policy[];
    permissions?: string[];
    userId?: string;
    loggedInAccountId?: string;
    pendingOwner?: PendingOwner;
    contributorLimit?: ContributorLimit;
    predefinedRoles?: PredefinedRoles;
}
interface User {
    /** User ID. */
    _id?: string;
    /**
     * Deprecated.
     * @deprecated
     */
    roles?: string[];
    /** User's email address. */
    email?: string;
    /** User's name. */
    name?: Name;
    /** URL to user's profile image, when provided. */
    profileImage?: string | null;
    /** Date the user joined the team. */
    joinedTeamAt?: Date | null;
    /**
     * Deprecated.
     * @deprecated
     */
    policyIds?: string[];
    /** Resources the user can access. */
    assignments?: Assignment[];
}
interface Name {
    /** User's first name. */
    firstName?: string;
    /** User's last name. */
    lastName?: string;
}
interface Team {
    accountId?: string;
    accountInfo?: AccountInfo;
    policyIds?: string[];
    joinedAt?: Date | null;
}
interface AccountInfo {
    accountName?: string;
    accountImage?: string;
    isTeam?: boolean;
}
interface SiteInvite {
    /**
     * Invite ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Site ID the user is invited to as a collaborator.
     * @format GUID
     * @readonly
     */
    siteId?: string;
    /**
     * Email address where the invite was sent.
     * @format EMAIL
     */
    email?: string;
    /** Role IDs included in the invite. */
    policyIds?: string[];
    /**
     * Deprecated. Use `inviterAccountId`.
     * @readonly
     * @deprecated
     */
    inviterId?: string;
    /**
     * Invite Status.
     *
     * Supported values:
     * - **Pending:** The invite has been sent and is valid, waiting for the user's response.
     * - **Used:** The invite has been accepted.
     * - **Deleted:** The invite has been deleted or revoked.
     * - **Declined:** The user declined the invite.
     * - **Expired:** The invite has expired without being accepted.
     */
    status?: InviteStatusWithLiterals;
    /** Link to accept the invite. */
    acceptLink?: string;
    /**
     * Inviting account ID.
     * @format GUID
     * @readonly
     */
    inviterAccountId?: string;
    /**
     * Account ID that accepted the invite. Populated only once the invite is accepted.
     * @format GUID
     * @readonly
     */
    acceptedByAccountId?: string | null;
    /** Date the invite was created. */
    dateCreated?: Date | null;
    /**
     * User's Wix Bookings staff ID, if relevant.
     * @format GUID
     */
    staffId?: string | null;
    /** Invite expiration date */
    expirationDate?: Date | null;
    /**
     * Location ids included in the invite
     * @format GUID
     * @readonly
     * @maxSize 20
     */
    locationIds?: string[];
}
/** Invite status stating whether the invite was accepted, waiting to be accepted, deleted etc.. */
declare enum InviteStatus {
    Pending = "Pending",
    Used = "Used",
    Deleted = "Deleted",
    Declined = "Declined",
    Expired = "Expired"
}
/** @enumType */
type InviteStatusWithLiterals = InviteStatus | 'Pending' | 'Used' | 'Deleted' | 'Declined' | 'Expired';
interface Policy {
    _id?: string;
    description?: string | null;
    name?: string | null;
    isCustom?: boolean;
    scopes?: string[];
}
interface PendingOwner {
    email?: string;
    expirationDate?: Date | null;
    acceptLink?: string;
}
interface ContributorLimit {
    contributorLimit?: number;
}
interface PredefinedRoles {
    roles?: PredefinedRole[];
}
interface PredefinedRole {
    titleKey?: string;
    roles?: Role[];
    title?: string | null;
    areaId?: string;
}
interface Role {
    _id?: string;
    deprecatedKey?: string;
    /** @deprecated */
    titleKey?: string;
    /** @deprecated */
    descriptionKey?: string;
    deprecated?: boolean;
    restrictFromLevel?: string;
    experiments?: string[];
    appDefIds?: string[];
    title?: string | null;
    description?: string | null;
    isCustom?: boolean;
    scopes?: string[];
    availableResourceTypes?: ResourceTypeWithLiterals[];
    availableConditions?: ConditionAttributeTypeWithLiterals[];
    limitToEditorTypes?: string[];
}
interface GetSiteContributorsV2Request {
    /** The locale of the request. Defaults to en-us. */
    locale?: string | null;
    /** The set of desired fields. */
    fields?: string[];
}
interface GetSiteContributorsV2Response {
    /** List of contributors of the given site. */
    contributors?: Contributor[];
    /** List of invites to contribute to the given site. */
    invites?: SiteInvite[];
    /** Quota information for contributors on the given site. */
    contributorsQuota?: ContributorsQuota;
}
interface ContributorsQuota extends ContributorsQuotaOptionsOneOf {
    /** Limited contributors quota details. */
    limitedOptions?: LimitedOptions;
    /** Type of contributors quota */
    type?: TypeWithLiterals;
}
/** @oneof */
interface ContributorsQuotaOptionsOneOf {
    /** Limited contributors quota details. */
    limitedOptions?: LimitedOptions;
}
/** Enum to represent different types of contributors quota. */
declare enum Type {
    UNKNOWN = "UNKNOWN",
    LIMITED = "LIMITED",
    UNLIMITED = "UNLIMITED"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN' | 'LIMITED' | 'UNLIMITED';
/** Details for a limited contributors quota. */
interface LimitedOptions {
    /** Maximum number of contributors allowed. */
    limit?: number;
    /** Number of accepted or pending invitations. */
    used?: number;
}
interface HandleSiteTransferRequest {
    originalOwnerAccountId?: string;
    newOwnerAccountId?: string;
    metaSiteId?: string;
    keepOriginalOwnerAsContributor?: boolean;
}
interface HandleSiteTransferResponse {
}
interface GetCurrentUserRolesRequest {
    /** The locale of the request. Defaults to en-us */
    locale?: string | null;
}
interface GetCurrentUserRolesResponse {
    roles?: LocalizedRole[];
}
interface LocalizedRole {
    name?: string;
    description?: string | null;
}
interface BulkGetUserRolesOnSiteRequest {
    /** @maxSize 5 */
    users?: UserSubject[];
    /** The locale of the request. Defaults to en-us */
    locale?: string | null;
}
interface UserSubject {
    userId?: string;
    accountId?: string;
}
interface BulkGetUserRolesOnSiteResponse {
    userRoles?: UserLocalizedRoles[];
}
interface UserLocalizedRoles {
    user?: UserSubject;
    roles?: LocalizedRole[];
}
interface BulkValidateEmailInviteEligibilityRequest {
    /**
     * List of emails to be checked for invite eligibility.
     * @minSize 1
     * @maxSize 10
     * @format EMAIL
     */
    emails?: string[];
}
interface BulkValidateEmailInviteEligibilityResponse {
    /** List of email invite eligibility results. */
    emailsEligibility?: EmailInviteEligibility[];
}
interface EmailInviteEligibility {
    /**
     * The email address being checked.
     * @format EMAIL
     */
    email?: string;
    /** Whether the email is eligible for an invite. */
    eligible?: boolean;
}
interface ChangeContributorRoleRequest {
    /**
     * Contributor's account ID.
     * @format GUID
     */
    accountId: string;
    /** New roles to assign to the contributor on the site. */
    newRoles: SiteRoleAssignment[];
}
interface SiteRoleAssignment {
    /** Role ID. Sometimes referred to as policy ID. See [Roles and Permissions](https://support.wix.com/en/article/roles-permissions-overview) for a list of available roles. */
    roleId?: string;
    /**
     * Assignment ID mapping the role to the contributor on the site.
     * @readonly
     */
    assignmentId?: string;
}
interface ChangeContributorRoleResponse {
    /** New roles assigned to the contributor on the site. */
    newAssignedRoles?: SiteRoleAssignment[];
}
interface ChangeContributorLocationRequest {
    /**
     * Contributor's account ID.
     * @format GUID
     */
    accountId: string;
    /**
     * New locations to assign to the contributor on the site.
     * @format GUID
     * @maxSize 20
     */
    newLocations: string[];
}
interface ChangeContributorLocationResponse {
    /**
     * New locations assigned to the contributor on the site.
     * @maxSize 20
     */
    newAssignedLocations?: SiteLocationAssignment[];
}
interface SiteLocationAssignment {
    /**
     * @format GUID
     * @maxSize 100
     */
    locationIds?: string[];
    /**
     * @readonly
     * @maxLength 20
     * @maxSize 999
     */
    assignmentIds?: string[];
}
interface QuerySiteContributorsRequest {
    filter?: QuerySiteContributorsFilter;
}
interface QuerySiteContributorsFilter {
    /**
     * Role IDs (referred to here as policy IDs) to return. See [Roles and Permissions](https://support.wix.com/en/article/roles-permissions-overview) for available roles.
     * @maxSize 20
     */
    policyIds?: string[];
    /**
     * Location IDs.
     * @format GUID
     * @maxSize 20
     */
    locationIds?: string[];
}
declare enum FieldSet {
    UNKNOWN = "UNKNOWN",
    /** Include only `account_id` and `account_owner_id` fields. */
    META_DATA = "META_DATA"
}
interface QuerySiteContributorsResponse {
    /** List of site contributors. */
    contributors?: ContributorV2[];
}
interface ContributorV2 {
    /** Contributor's account ID. */
    accountId?: string | null;
    /** User ID of the owner of the account that the contributor has joined. */
    accountOwnerId?: string | null;
}
interface GetContributorsQuotaRequest {
}
interface GetContributorsQuotaResponse {
    /** Quota information for contributors on the given site. */
    contributorsQuota?: ContributorsQuota;
}
interface GetAppContributorsRequest {
    /** @format GUID */
    appId?: string;
    /** The locale of the request. Defaults to en-us. */
    locale?: string | null;
}
interface GetAppContributorsResponse {
    contributors?: Contributor[];
    invites?: AppInvite[];
}
interface AppInvite {
    /**
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * TODO: amitis - remove this comment after the next merge
     * @format EMAIL
     */
    destEmail?: string;
    /**
     * @readonly
     * @maxLength 20
     */
    status?: string;
    /**
     * @format WEB_URL
     * @readonly
     */
    acceptLink?: string;
    /** @maxLength 50 */
    invitePurpose?: string | null;
    /** @maxSize 10 */
    policies?: AssignedPolicy[];
    /** @readonly */
    expirationDate?: Date | null;
    /** @readonly */
    dateCreated?: Date | null;
    /** @readonly */
    dateUpdated?: Date | null;
}
interface GetSiteContributorsV2Options {
    /** The locale of the request. Defaults to en-us. */
    locale?: string | null;
    /** The set of desired fields. */
    fields?: string[];
}
interface ChangeRoleOptions {
    /** New roles to assign to the contributor on the site. */
    newRoles: SiteRoleAssignment[];
}
interface ChangeContributorLocationOptions {
    /**
     * New locations to assign to the contributor on the site.
     * @format GUID
     * @maxSize 20
     */
    newLocations: string[];
}
interface QuerySiteContributorsOptions {
    filter?: QuerySiteContributorsFilter;
}

export { type UserLocalizedRoles as $, type Assignment as A, type Role as B, type ChangeRoleOptions as C, type GetSiteContributorsV2Request as D, type GetSiteContributorsV2Response as E, FieldSet as F, type GetSiteContributorsRequest as G, type ContributorsQuota as H, InviteStatus as I, type ContributorsQuotaOptionsOneOf as J, type LimitedOptions as K, type LocationsRestriction as L, type HandleSiteTransferRequest as M, type Name as N, type HandleSiteTransferResponse as O, type PersonMetaData as P, type QuerySiteContributorsOptions as Q, ResourceType as R, SubjectType as S, Type as T, type User as U, type GetCurrentUserRolesRequest as V, type GetCurrentUserRolesResponse as W, type LocalizedRole as X, type BulkGetUserRolesOnSiteRequest as Y, type UserSubject as Z, type BulkGetUserRolesOnSiteResponse as _, type ChangeContributorRoleResponse as a, type BulkValidateEmailInviteEligibilityRequest as a0, type BulkValidateEmailInviteEligibilityResponse as a1, type EmailInviteEligibility as a2, type ChangeContributorRoleRequest as a3, type SiteRoleAssignment as a4, type ChangeContributorLocationRequest as a5, type SiteLocationAssignment as a6, type QuerySiteContributorsRequest as a7, type QuerySiteContributorsFilter as a8, type ContributorV2 as a9, type GetContributorsQuotaRequest as aa, type GetContributorsQuotaResponse as ab, type GetAppContributorsRequest as ac, type GetAppContributorsResponse as ad, type AppInvite as ae, type GetSiteContributorsV2Options as af, type ChangeContributorLocationOptions as b, type ChangeContributorLocationResponse as c, type QuerySiteContributorsResponse as d, ConditionAttributeType as e, SubjectContextType as f, type Contributor as g, type AssignedPolicy as h, type Restriction as i, type RestrictionRestrictionsOneOf as j, type Resource as k, type Conditions as l, type Condition as m, type SiteRestriction as n, type CompanionResource as o, type Subject as p, type SubjectContext as q, type GetSiteContributorsResponse as r, type Team as s, type AccountInfo as t, type SiteInvite as u, type Policy as v, type PendingOwner as w, type ContributorLimit as x, type PredefinedRoles as y, type PredefinedRole as z };
