// src/identity-v1-contributor-contributors.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/identity-v1-contributor-contributors.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      },
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/app/accept",
        destPath: "/app/accept"
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/roles-management-web",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "platform.rise.ai": [
      {
        srcPath: "/v2/contributors",
        destPath: "/v2/contributors"
      },
      {
        srcPath: "/contributor/change/role",
        destPath: "/contributor/change/role"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/roles-management",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management/roles",
        destPath: "/roles"
      },
      {
        srcPath: "/roles-management/team",
        destPath: "/team"
      },
      {
        srcPath: "/roles-management/v3/team",
        destPath: "/v3/team"
      },
      {
        srcPath: "/roles-management/v2/team",
        destPath: "/v2/team"
      },
      {
        srcPath: "/roles-management/contributor/change",
        destPath: "/contributor/change"
      },
      {
        srcPath: "/roles-management/v2/contributors",
        destPath: "/v2/contributors"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_contributors";
function getSiteContributorsV2(payload) {
  function __getSiteContributorsV2({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "fields" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.GetSiteContributorsV2",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/v2/contributors",
        data: serializedData,
        host
      }),
      params: toURLSearchParams(serializedData),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contributors.joinedAt" },
            { path: "invites.dateCreated" },
            { path: "invites.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getSiteContributorsV2;
}
function changeRole(payload) {
  function __changeRole({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "PUT",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.ChangeRole",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/contributor/change/role",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __changeRole;
}
function changeContributorLocation(payload) {
  function __changeContributorLocation({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "PUT",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.ChangeContributorLocation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/contributor/change/locations",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __changeContributorLocation;
}
function querySiteContributors(payload) {
  function __querySiteContributors({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.QuerySiteContributors",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/v2/contributors/query",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __querySiteContributors;
}
function getContributorsQuota(payload) {
  function __getContributorsQuota({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.GetContributorsQuota",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/v2/contributors/quota",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getContributorsQuota;
}

// src/identity-v1-contributor-contributors.universal.ts
var ResourceType = /* @__PURE__ */ ((ResourceType2) => {
  ResourceType2["UNKNOWN_RESOURCE_TYPE"] = "UNKNOWN_RESOURCE_TYPE";
  ResourceType2["SITE"] = "SITE";
  return ResourceType2;
})(ResourceType || {});
var ConditionAttributeType = /* @__PURE__ */ ((ConditionAttributeType2) => {
  ConditionAttributeType2["UNKNOWN_CONDITION_TYPE"] = "UNKNOWN_CONDITION_TYPE";
  ConditionAttributeType2["FOLDER"] = "FOLDER";
  return ConditionAttributeType2;
})(ConditionAttributeType || {});
var SubjectType = /* @__PURE__ */ ((SubjectType2) => {
  SubjectType2["UNKNOWN"] = "UNKNOWN";
  SubjectType2["ACCOUNT"] = "ACCOUNT";
  SubjectType2["USER"] = "USER";
  SubjectType2["USER_GROUP"] = "USER_GROUP";
  SubjectType2["MEMBER_GROUP"] = "MEMBER_GROUP";
  SubjectType2["VISITOR_GROUP"] = "VISITOR_GROUP";
  SubjectType2["EXTERNAL_APP"] = "EXTERNAL_APP";
  SubjectType2["ACCOUNT_GROUP"] = "ACCOUNT_GROUP";
  SubjectType2["WIX_APP"] = "WIX_APP";
  return SubjectType2;
})(SubjectType || {});
var SubjectContextType = /* @__PURE__ */ ((SubjectContextType2) => {
  SubjectContextType2["UNKNOWN_CTX"] = "UNKNOWN_CTX";
  SubjectContextType2["ORG_CTX"] = "ORG_CTX";
  SubjectContextType2["ACCOUNT_CTX"] = "ACCOUNT_CTX";
  return SubjectContextType2;
})(SubjectContextType || {});
var InviteStatus = /* @__PURE__ */ ((InviteStatus2) => {
  InviteStatus2["Pending"] = "Pending";
  InviteStatus2["Used"] = "Used";
  InviteStatus2["Deleted"] = "Deleted";
  InviteStatus2["Declined"] = "Declined";
  InviteStatus2["Expired"] = "Expired";
  return InviteStatus2;
})(InviteStatus || {});
var Type = /* @__PURE__ */ ((Type2) => {
  Type2["UNKNOWN"] = "UNKNOWN";
  Type2["LIMITED"] = "LIMITED";
  Type2["UNLIMITED"] = "UNLIMITED";
  return Type2;
})(Type || {});
var FieldSet = /* @__PURE__ */ ((FieldSet2) => {
  FieldSet2["UNKNOWN"] = "UNKNOWN";
  FieldSet2["META_DATA"] = "META_DATA";
  return FieldSet2;
})(FieldSet || {});
async function getSiteContributorsV22(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    locale: options?.locale,
    fields: options?.fields
  });
  const reqOpts = getSiteContributorsV2(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          locale: "$[0].locale",
          fields: "$[0].fields"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function changeRole2(accountId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    accountId,
    newRoles: options?.newRoles
  });
  const reqOpts = changeRole(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          accountId: "$[0]",
          newRoles: "$[1].newRoles"
        },
        singleArgumentUnchanged: false
      },
      ["accountId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function changeContributorLocation2(accountId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    accountId,
    newLocations: options?.newLocations
  });
  const reqOpts = changeContributorLocation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          accountId: "$[0]",
          newLocations: "$[1].newLocations"
        },
        singleArgumentUnchanged: false
      },
      ["accountId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function querySiteContributors2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    filter: options?.filter
  });
  const reqOpts = querySiteContributors(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { filter: "$[0].filter" },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getContributorsQuota2() {
  const { httpClient, sideEffects } = arguments[0];
  const payload = renameKeysFromSDKRequestToRESTRequest({});
  const reqOpts = getContributorsQuota(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {},
        singleArgumentUnchanged: false
      },
      []
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/identity-v1-contributor-contributors.public.ts
function getSiteContributorsV23(httpClient) {
  return (options) => getSiteContributorsV22(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function changeRole3(httpClient) {
  return (accountId, options) => changeRole2(
    accountId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function changeContributorLocation3(httpClient) {
  return (accountId, options) => changeContributorLocation2(
    accountId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function querySiteContributors3(httpClient) {
  return (options) => querySiteContributors2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function getContributorsQuota3(httpClient) {
  return () => getContributorsQuota2(
    // @ts-ignore
    { httpClient }
  );
}

// src/identity-v1-contributor-contributors.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var getSiteContributorsV24 = /* @__PURE__ */ createRESTModule(getSiteContributorsV23);
var changeRole4 = /* @__PURE__ */ createRESTModule(changeRole3);
var changeContributorLocation4 = /* @__PURE__ */ createRESTModule(changeContributorLocation3);
var querySiteContributors4 = /* @__PURE__ */ createRESTModule(querySiteContributors3);
var getContributorsQuota4 = /* @__PURE__ */ createRESTModule(getContributorsQuota3);
export {
  ConditionAttributeType,
  FieldSet,
  InviteStatus,
  ResourceType,
  SubjectContextType,
  SubjectType,
  Type,
  changeContributorLocation4 as changeContributorLocation,
  changeRole4 as changeRole,
  getContributorsQuota4 as getContributorsQuota,
  getSiteContributorsV24 as getSiteContributorsV2,
  querySiteContributors4 as querySiteContributors
};
//# sourceMappingURL=index.mjs.map