// src/identity-v1-contributor-contributors.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      },
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/app/accept",
        destPath: "/app/accept"
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/roles-management-web",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/contributors/accept",
        destPath: "/contributors/accept"
      },
      {
        srcPath: "/team/accept",
        destPath: "/team/accept"
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/roles-management-web",
        destPath: ""
      }
    ],
    "platform.rise.ai": [
      {
        srcPath: "/v2/contributors",
        destPath: "/v2/contributors"
      },
      {
        srcPath: "/contributor/change/role",
        destPath: "/contributor/change/role"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/roles-management",
        destPath: ""
      },
      {
        srcPath: "/roles-management-web",
        destPath: ""
      },
      {
        srcPath: "/roles-management/roles",
        destPath: "/roles"
      },
      {
        srcPath: "/roles-management/team",
        destPath: "/team"
      },
      {
        srcPath: "/roles-management/v3/team",
        destPath: "/v3/team"
      },
      {
        srcPath: "/roles-management/v2/team",
        destPath: "/v2/team"
      },
      {
        srcPath: "/roles-management/contributor/change",
        destPath: "/contributor/change"
      },
      {
        srcPath: "/roles-management/v2/contributors",
        destPath: "/v2/contributors"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_contributors";
function getSiteContributorsV2(payload) {
  function __getSiteContributorsV2({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "fields" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.GetSiteContributorsV2",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/v2/contributors",
        data: serializedData,
        host
      }),
      params: toURLSearchParams(serializedData),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contributors.joinedAt" },
            { path: "invites.dateCreated" },
            { path: "invites.expirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getSiteContributorsV2;
}
function changeRole(payload) {
  function __changeRole({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "PUT",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.ChangeRole",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/contributor/change/role",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __changeRole;
}
function changeContributorLocation(payload) {
  function __changeContributorLocation({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "PUT",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.ChangeContributorLocation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/contributor/change/locations",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __changeContributorLocation;
}
function querySiteContributors(payload) {
  function __querySiteContributors({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.QuerySiteContributors",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/v2/contributors/query",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __querySiteContributors;
}
function getContributorsQuota(payload) {
  function __getContributorsQuota({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.v1.contributor",
      method: "GET",
      methodFqn: "com.wixpress.roles.management.api.SiteRolesManagementService.GetContributorsQuota",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressRolesManagementApiSiteRolesManagementServiceUrl({
        protoPath: "/v2/contributors/quota",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getContributorsQuota;
}

// src/identity-v1-contributor-contributors.meta.ts
function getSiteContributorsV22() {
  const payload = {};
  const getRequestOptions = getSiteContributorsV2(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v2/contributors",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function changeRole2() {
  const payload = {};
  const getRequestOptions = changeRole(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/contributor/change/role",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function changeContributorLocation2() {
  const payload = {};
  const getRequestOptions = changeContributorLocation(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/contributor/change/locations",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function querySiteContributors2() {
  const payload = {};
  const getRequestOptions = querySiteContributors(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v2/contributors/query",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getContributorsQuota2() {
  const payload = {};
  const getRequestOptions = getContributorsQuota(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v2/contributors/quota",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  changeContributorLocation2 as changeContributorLocation,
  changeRole2 as changeRole,
  getContributorsQuota2 as getContributorsQuota,
  getSiteContributorsV22 as getSiteContributorsV2,
  querySiteContributors2 as querySiteContributors
};
//# sourceMappingURL=meta.mjs.map