import { J as GetSiteContributorsV2Request$1, a as GetSiteContributorsV2Response$1, a5 as ChangeContributorRoleRequest$1, b as ChangeContributorRoleResponse$1, a7 as ChangeContributorLocationRequest$1, d as ChangeContributorLocationResponse$1, a9 as QuerySiteContributorsRequest$1, e as QuerySiteContributorsResponse$1, ac as GetContributorsQuotaRequest$1, f as GetContributorsQuotaResponse$1 } from './identity-v1-contributor-contributors.universal-DLzpcW8B.js';

interface Contributor {
    /** Contributor's metadata. */
    metaData?: PersonMetaData;
    /** Whether the contributor account is a team account. */
    isTeam?: boolean | null;
    /** Date that the contributor joined the site. */
    joinedAt?: Date | null;
    /** Email address that received the invite. */
    invitedEmail?: string | null;
    /** Whether the contributor account is a client account. */
    isClient?: boolean | null;
    /**
     * Contributor's user ID.
     * @format GUID
     * @readonly
     */
    id?: string;
}
interface PersonMetaData {
    /** Contributor's account ID. */
    id?: string;
    /** Contributor's full name. */
    fullName?: string | null;
    /** URL for contributor's profile image. */
    imageUrl?: string | null;
    /** Contributor's email address. */
    email?: string | null;
    /** Contributor's access to assets and their assigned role (`policy`) for that asset. */
    assignments?: Assignment[];
}
interface Assignment {
    /** Role assigned to the user. */
    policy?: AssignedPolicy;
    /** Unique ID for this specific assignment. */
    assignmentId?: string;
    /** Identity assigned to the asset in an assignment, referred to as subject. Supported subjects include user IDs, account IDs, and app IDs. */
    subject?: Subject;
}
interface AssignedPolicy {
    /** Role ID. */
    policyId?: string;
    /** Role title. */
    title?: string | null;
    /** Role description. */
    description?: string | null;
}
interface Subject {
    /** ID of identity assigned to the asset. */
    id?: string;
    /** Type of identity assigned to the asset. Supported subject types include user IDs, account IDs, and app IDs. */
    subjectType?: SubjectTypeWithLiterals;
    /** Context of identity assigned to the asset. For example, a `subjectType` = `USER` will have `context` = `ACCOUNT`. */
    context?: SubjectContext;
}
declare enum SubjectType {
    UNKNOWN = "UNKNOWN",
    ACCOUNT = "ACCOUNT",
    USER = "USER",
    USER_GROUP = "USER_GROUP",
    MEMBER_GROUP = "MEMBER_GROUP",
    VISITOR_GROUP = "VISITOR_GROUP",
    EXTERNAL_APP = "EXTERNAL_APP",
    ACCOUNT_GROUP = "ACCOUNT_GROUP",
    WIX_APP = "WIX_APP"
}
/** @enumType */
type SubjectTypeWithLiterals = SubjectType | 'UNKNOWN' | 'ACCOUNT' | 'USER' | 'USER_GROUP' | 'MEMBER_GROUP' | 'VISITOR_GROUP' | 'EXTERNAL_APP' | 'ACCOUNT_GROUP' | 'WIX_APP';
interface SubjectContext {
    id?: string;
    contextType?: SubjectContextTypeWithLiterals;
}
declare enum SubjectContextType {
    UNKNOWN_CTX = "UNKNOWN_CTX",
    ORG_CTX = "ORG_CTX",
    ACCOUNT_CTX = "ACCOUNT_CTX"
}
/** @enumType */
type SubjectContextTypeWithLiterals = SubjectContextType | 'UNKNOWN_CTX' | 'ORG_CTX' | 'ACCOUNT_CTX';
interface SiteInvite {
    /**
     * Invite ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * Site ID the user is invited to as a collaborator.
     * @format GUID
     * @readonly
     */
    siteId?: string;
    /**
     * Email address where the invite was sent.
     * @format EMAIL
     */
    email?: string;
    /** Role IDs included in the invite. */
    policyIds?: string[];
    /**
     * Deprecated. Use `inviterAccountId`.
     * @readonly
     * @deprecated
     */
    inviterId?: string;
    /**
     * Invite Status.
     *
     * Supported values:
     * - **Pending:** The invite has been sent and is valid, waiting for the user's response.
     * - **Used:** The invite has been accepted.
     * - **Deleted:** The invite has been deleted or revoked.
     * - **Declined:** The user declined the invite.
     * - **Expired:** The invite has expired without being accepted.
     */
    status?: InviteStatusWithLiterals;
    /** Link to accept the invite. */
    acceptLink?: string;
    /**
     * Inviting account ID.
     * @format GUID
     * @readonly
     */
    inviterAccountId?: string;
    /**
     * Account ID that accepted the invite. Populated only once the invite is accepted.
     * @format GUID
     * @readonly
     */
    acceptedByAccountId?: string | null;
    /** Date the invite was created. */
    dateCreated?: Date | null;
    /**
     * User's Wix Bookings staff ID, if relevant.
     * @format GUID
     */
    staffId?: string | null;
    /** Invite expiration date */
    expirationDate?: Date | null;
    /**
     * Location ids included in the invite
     * @format GUID
     * @readonly
     * @maxSize 20
     */
    locationIds?: string[];
}
/** Invite status stating whether the invite was accepted, waiting to be accepted, deleted etc.. */
declare enum InviteStatus {
    Pending = "Pending",
    Used = "Used",
    Deleted = "Deleted",
    Declined = "Declined",
    Expired = "Expired"
}
/** @enumType */
type InviteStatusWithLiterals = InviteStatus | 'Pending' | 'Used' | 'Deleted' | 'Declined' | 'Expired';
interface GetSiteContributorsV2Request {
    /** The locale of the request. Defaults to en-us. */
    locale?: string | null;
    /** The set of desired fields. */
    fields?: string[];
}
interface GetSiteContributorsV2Response {
    /** List of contributors of the given site. */
    contributors?: Contributor[];
    /** List of invites to contribute to the given site. */
    invites?: SiteInvite[];
    /** Quota information for contributors on the given site. */
    contributorsQuota?: ContributorsQuota;
}
interface ContributorsQuota extends ContributorsQuotaOptionsOneOf {
    /** Limited contributors quota details. */
    limitedOptions?: LimitedOptions;
    /** Type of contributors quota */
    type?: TypeWithLiterals;
}
/** @oneof */
interface ContributorsQuotaOptionsOneOf {
    /** Limited contributors quota details. */
    limitedOptions?: LimitedOptions;
}
/** Enum to represent different types of contributors quota. */
declare enum Type {
    UNKNOWN = "UNKNOWN",
    LIMITED = "LIMITED",
    UNLIMITED = "UNLIMITED"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN' | 'LIMITED' | 'UNLIMITED';
/** Details for a limited contributors quota. */
interface LimitedOptions {
    /** Maximum number of contributors allowed. */
    limit?: number;
    /** Number of accepted or pending invitations. */
    used?: number;
}
interface ChangeContributorRoleRequest {
    /**
     * Contributor's account ID.
     * @format GUID
     */
    accountId: string;
    /** New roles to assign to the contributor on the site. */
    newRoles: SiteRoleAssignment[];
}
interface SiteRoleAssignment {
    /** Role ID. Sometimes referred to as policy ID. See [Roles and Permissions](https://support.wix.com/en/article/roles-permissions-overview) for a list of available roles. */
    roleId?: string;
    /**
     * Assignment ID mapping the role to the contributor on the site.
     * @readonly
     */
    assignmentId?: string;
}
interface ChangeContributorRoleResponse {
    /** New roles assigned to the contributor on the site. */
    newAssignedRoles?: SiteRoleAssignment[];
}
interface ChangeContributorLocationRequest {
    /**
     * Contributor's account ID.
     * @format GUID
     */
    accountId: string;
    /**
     * New locations to assign to the contributor on the site.
     * @format GUID
     * @maxSize 20
     */
    newLocations: string[];
}
interface ChangeContributorLocationResponse {
    /**
     * New locations assigned to the contributor on the site.
     * @maxSize 20
     */
    newAssignedLocations?: SiteLocationAssignment[];
}
interface SiteLocationAssignment {
    /**
     * @format GUID
     * @maxSize 100
     */
    locationIds?: string[];
    /**
     * @readonly
     * @maxLength 20
     * @maxSize 999
     */
    assignmentIds?: string[];
}
interface QuerySiteContributorsRequest {
    filter?: QuerySiteContributorsFilter;
}
interface QuerySiteContributorsFilter {
    /**
     * Role IDs (referred to here as policy IDs) to return. See [Roles and Permissions](https://support.wix.com/en/article/roles-permissions-overview) for available roles.
     * @maxSize 20
     */
    policyIds?: string[];
    /**
     * Location IDs.
     * @format GUID
     * @maxSize 20
     */
    locationIds?: string[];
}
interface QuerySiteContributorsResponse {
    /** List of site contributors. */
    contributors?: ContributorV2[];
}
interface ContributorV2 {
    /** Contributor's account ID. */
    accountId?: string | null;
    /** User ID of the owner of the account that the contributor has joined. */
    accountOwnerId?: string | null;
}
interface GetContributorsQuotaRequest {
}
interface GetContributorsQuotaResponse {
    /** Quota information for contributors on the given site. */
    contributorsQuota?: ContributorsQuota;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getSiteContributorsV2(): __PublicMethodMetaInfo<'GET', {}, GetSiteContributorsV2Request$1, GetSiteContributorsV2Request, GetSiteContributorsV2Response$1, GetSiteContributorsV2Response>;
declare function changeRole(): __PublicMethodMetaInfo<'PUT', {}, ChangeContributorRoleRequest$1, ChangeContributorRoleRequest, ChangeContributorRoleResponse$1, ChangeContributorRoleResponse>;
declare function changeContributorLocation(): __PublicMethodMetaInfo<'PUT', {}, ChangeContributorLocationRequest$1, ChangeContributorLocationRequest, ChangeContributorLocationResponse$1, ChangeContributorLocationResponse>;
declare function querySiteContributors(): __PublicMethodMetaInfo<'GET', {}, QuerySiteContributorsRequest$1, QuerySiteContributorsRequest, QuerySiteContributorsResponse$1, QuerySiteContributorsResponse>;
declare function getContributorsQuota(): __PublicMethodMetaInfo<'GET', {}, GetContributorsQuotaRequest$1, GetContributorsQuotaRequest, GetContributorsQuotaResponse$1, GetContributorsQuotaResponse>;

export { type __PublicMethodMetaInfo, changeContributorLocation, changeRole, getContributorsQuota, getSiteContributorsV2, querySiteContributors };
